<?php

switch ($messaggio) {

case "Inserisci i prezzi per l'anno":  		$messaggio = "De prijzen voor jaar"; break;
case "Prezzi della":  				$messaggio = "Prijzen van"; break;
case "tariffa":  				$messaggio = "tarief"; break;
case "soprannominata":  			$messaggio = "genaamd"; break;
case "Dal":  					$messaggio = "Van"; break;
case "al":  					$messaggio = "tot"; break;
case "inserisci i nuovi prezzi":  		$messaggio = "Voeg de nieuwe prijzen in"; break;
case "modifica i prezzi già inseriti":  	$messaggio = "wijzig reeds ingebrachte prijzen"; break;
case "Costi aggiuntivi":  			$messaggio = "Extra kosten"; break;
case "Nome del nuovo costo aggiuntivo":		$messaggio = "Naam nieuwe extra kosten"; break;
case "da applicare":  				$messaggio = "toe te passen"; break;
case "sempre":  				$messaggio = "altijd"; break;
case "su richiesta":  				$messaggio = "op aanvraag"; break;
case "chiedi per quanto deve essere moltiplicato":	$messaggio = "vraag met hoeveel het vermenigvuldigd moet worden"; break;
case "considera il costo finale come letto(i) aggiuntivo(i)":	$messaggio = "beschouwd deze single kosten als extra bed(den)"; break;
case "numero di settimane":  			$messaggio = "aantal weken"; break;
case "numero di giorni":  			$messaggio = "aantal dagen"; break;
case "tutte":  					$messaggio = "allen"; break;
case "tutti":  					$messaggio = "allen"; break;
case "tutte meno una":  			$messaggio = "allen min een"; break;
case "tutti meno uno":  			$messaggio = "allen min een"; break;
case "chiedere":  				$messaggio = "vraag"; break;
case "considera il costo settimanale come letto(i) aggiuntivo(i)":	$messaggio = "beschouw deze wekelijkse kosten als extra bed(den))"; break;
case "considera il costo giornaliero come letto(i) aggiuntivo(i)":	$messaggio = "beschouw deze dagelijkse kosten als extra bed(den)"; break;
case "della tariffa arrotondato a":  		$messaggio = "van het tarief afgerond naar"; break;
case "considera il costo percentuale come letto(i) aggiuntivo(i)":	$messaggio = "beschouw deze percentage kosten als extra bed(den)"; break;
case "Procedi nell'inserimento del nuovo costo aggiuntivo":	$messaggio = "Ga verder met invoeren van de nieuwe extra kosten"; break;
case "Caparra":  				$messaggio = "Deposito"; break;
case "arrotondata a":  				$messaggio = "afgerond naar"; break;
case "Inserisci o modifica la caparra":  	$messaggio = "Voeg in of wijzig het deposito"; break;
case "Vedi i prezzi già inseriti":  		$messaggio = "Bekijk de reeds ingevoegde prijzen"; break;
case "Torna al menù principale":  		$messaggio = "Terug naar het hoofdmenu"; break;
case "Si deve inserire la percentuale":  	$messaggio = "U moet het percentage invoeren"; break;
case "La caparra è stata modificata":  		$messaggio = "Het depsoito is gewijzigd"; break;
case "Si deve specificare quando applicare il costo di fine locazione":	$messaggio = "U moet kiezen hoe U de single kosten wilt toevoegen"; break;
case "Si deve inserire il nome del costo aggiuntivo":	$messaggio = "U moet de naam van de extra kosten invoeren"; break;
case "Il costo aggiuntivo finale":  		$messaggio = "De single extra kosten"; break;
case "già esiste, vai alla pagina di visualizzazione periodi e tariffe per cancellarlo":	$messaggio = "bestaat reeds, ga naar de pagina van de periodes en tarieven om die te verwijderen"; break;
case "Per chiedere il numero da moltiplicare, il costo aggiuntivo finale non deve essere applicato automaticamente":	$messaggio = "Vraag met hoeveel keer de single extra kosten moet worden vermengivuldigd worden, moet niet automatisch wroden toegevoegd"; break;
case "Si deve specificare quando applicare il costo settimanale":	$messaggio = "U moet kiezen hoe de wekelijkse kosten moeten worden toegevoegd"; break;
case "Si deve specificare quando applicare il costo giornaliero":	$messaggio = "U moet kiezen hoe de dagelijkse kosten moeten worden toegevoegd"; break;
case "e il numero di settimane":  		$messaggio = "en het aantal weken"; break;
case "e il numero di giorni":  			$messaggio = "en het aantal dagen"; break;
case "Per chiedere il numero di settimane o il numero da moltiplicare, il costo aggiuntivo settimanale non deve essere applicato automaticamente":	$messaggio = "Te vragen het aantal weken of met hoeveeel de wekelijkse extra kosten vermenigvuldigd moet worden, kosten moeten niet automatisch worden toegevoegd"; break;
case "Per chiedere il numero di giorni o il numero da moltiplicare, il costo aggiuntivo giornaliero non deve essere applicato automaticamente":	$messaggio = "Te vragen het aantal dagen of met hoeveeel de dagelijkse extra kosten vermenigvuldigd moet worden, kosten moeten niet automatisch worden toegevoegd"; break;
case "Il costo aggiuntivo settimanale":  	$messaggio = "De wekelikjkse extra kosten"; break;
case "Il costo aggiuntivo giornaliero":  	$messaggio = "De dagelijkse extra kosten"; break;
case "Si deve specificare quando applicare il costo percentuale":	$messaggio = "U moet kiezen hoe U de percentage kosten worden toegevoegd"; break;
case "e il valore dell'arrotondamento":		$messaggio = "an de waarde afgerond naar"; break;
case "Per chiedere per quanto deve essere moltiplicato il costo aggiuntivo percentuale non deve essere applicato automaticamente":	$messaggio = "Te vragen met hoeveel het percentage extra kosten moet worden vermendigvuldigd, kosten moeten niet auotomatisch worden toegevoegd"; break;
case "è stato inserito":  			$messaggio = "is ingevoegd"; break;
case "Nessun dato è stato inserito":  		$messaggio = "Er is geen data ingevoegd"; break;
case "Il soprannome della":  			$messaggio = "De naam van"; break;
case "già esiste, usa il tasto \"modifica i prezzi già inseriti\" per cambiarlo o non metterlo per inserire prezzi per nuovi periodi":	$messaggio = "Bestaat reeds, gebruik de knop \"wijzig reeds ingevoerde prijzen\" om dit te wijzigen, of voeg het niet in: voeg prijzen in de nieuwe periodes"; break;
case "Il soprannome":  				$messaggio = "De naam"; break;
case "già esiste, ne devi usare un'altro":  	$messaggio = "bestaat reeds, U moet een andere gebruiken"; break;
case "Le date del periodo numero":  		$messaggio = "De datums van het periode nummer"; break;
case "sono sbagliate":  			$messaggio = "zijn verkeerd"; break;
case "Il periodo":  				$messaggio = "De periode"; break;
case "si sovrappone ad un periodo precedente":	$messaggio = "overlap naar een anders periode"; break;
case "Un prezzo nel periodo numero":  		$messaggio = "Een prijs in periode nummer"; break;
case "esiste già, usa il tasto \"modifica i prezzi già inseriti\" per cambiarlo":	$messaggio = "bestaat reeds, gebruik de knop \"wijzig reeds ingevoegde prijzen\" om te wijzigen"; break;
case "è stato cambiato":  			$messaggio = "is gewijzigd"; break;
case "Il prezzo del periodo":  			$messaggio = "De prijs van periode"; break;
case "è stato inserito":  			$messaggio = "is ingevoegd"; break;
case "Il prezzo del periodo numero":  		$messaggio = "De prijs van periode nummer"; break;
case "è sbagliato":  				$messaggio = "is verkeerd"; break;
case "I soldi del costo finale sono sbagliati":	$messaggio = "Het geld voor single is verkeerd"; break;
case "I soldi del costo settimanale sono sbagliati":	$messaggio = "Bedrag voor wekelijkse kosten is verkeerd"; break;
case "I soldi del costo giornaliero sono sbagliati":	$messaggio = "Bedrag voor dagelijkse kosten is verkeerd"; break;
case "I soldi del costo percentuale sono sbagliati":	$messaggio = "Bedrag voor percentage kosten is verkeerd"; break;
case "Inserzione per settimane":  		$messaggio = "Voeg in op wekelijkse basis"; break;
case "Settimane dal":  				$messaggio = "Weken vanaf"; break;
case "Dom/Lun":  				$messaggio = "Zon/Maa"; break;
case "Lun/Mar":  				$messaggio = "Maa/Din"; break;
case "Mar/Mer":  				$messaggio = "Din/Woe"; break;
case "Mer/Gio":  				$messaggio = "Woe/Don"; break;
case "Gio/Ven":  				$messaggio = "Don/Vri"; break;
case "Ven/Sab":  				$messaggio = "Vri/Zat"; break;
case "Sab/Dom":  				$messaggio = "Zat/Zon"; break;
case "inserisci o modifica i prezzi":  		$messaggio = "Voeg in of wijzig de prijzen"; break;
case "Le date sono sbagliate":  		$messaggio = "Datums zijn verkeerd"; break;
case "Il formato dei soldi è sbagliato":  	$messaggio = "Geld formaat is verkeerd"; break;
case "I prezzi per le settimane dal":  		$messaggio = "De prijs voor weken van"; break;
case "della <b>tariffa":  			$messaggio = "van <b>tarief"; break;
case "sono stati inseriti":  			$messaggio = "zijn ingevoegd"; break;
case "si":  					$messaggio = "ja"; break;
case "no":  					$messaggio = "nee"; break;
case "assegnato automaticamente con tariffe":  	$messaggio = "automatisch toegewezen voor tarieven"; break;
case "nessuna":  				$messaggio = "niemand"; break;
case "scegliere":  				$messaggio = "kies"; break;
case "mostrare nella pagina di inserzione prenotazioni":	$messaggio = "display in reserverings invoegpagina"; break;
case "Torna indietro":  			$messaggio = "Ga terug"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>finale</b>":	$messaggio = "Kies het tarief waarbij automatisch <b>single</b> extra kosten worden toegevoegd"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>settimanale</b>":	$messaggio = "Kies het tarief waarbij automatisch de <b>wekelijkse</b> extra kosten worden toegevoegd"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>giornaliero</b>":	$messaggio = "Kies het tarief waarbij automatisch de <b>dagelijkse</b> extra kosten worden toegevoegd"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>percentuale</b>":	$messaggio = "Kies het tarief waarbij automatisch het <b>percentage</b> extra kosten worden toegevoegd"; break;
case "Continua":  				$messaggio = "Ga verder"; break;
case "Tipo di costo aggiuntivo":  		$messaggio = "Extra kosten type"; break;
case "settimanale":  				$messaggio = "wekelijks"; break;
case "giornaliero":  				$messaggio = "dagelijks"; break;
case "il prezzo totale":  			$messaggio = "totale prijs"; break;
case "la caparra":  				$messaggio = "het deposito"; break;
case "totale meno caparra":  			$messaggio = "totaa min deposito"; break;
case "esattamente":  				$messaggio = "exact"; break;
case "settimane":  				$messaggio = "weken"; break;
case "giorni":  				$messaggio = "dagen"; break;
case "Se possibile":  				$messaggio = "Indien mogelijk"; break;
case "Sempre":  				$messaggio = "Altijd"; break;
case "Associare a specifiche settimane della prenotazione":	$messaggio = "Gekoppeld aam de specifieke weken van reservering"; break;
case "Associare a specifici giorni della prenotazione":	$messaggio = "Gekoppeld aam de specifieke dagen van reservering"; break;
case "Tutte":  					$messaggio = "Allen"; break;
case "Tutti":  					$messaggio = "Allen"; break;
case "Tutte meno":  				$messaggio = "Alles min"; break;
case "Tutti meno":  				$messaggio = "Alles min"; break;
case "la prima":  				$messaggio = "de eerste"; break;
case "il primo":  				$messaggio = "de eerste"; break;
case "l'ultima":  				$messaggio = "de laatste"; break;
case "l'ultimo":  				$messaggio = "de laatste"; break;
case "Chiedere":  				$messaggio = "Vraag"; break;
case "settimane sì":  				$messaggio = "weken ja"; break;
case "giorni sì":  				$messaggio = "dagen ja"; break;
case "settimane no":  				$messaggio = "weken nee"; break;
case "giorni no":  				$messaggio = "dagen nee"; break;
case "e":  					$messaggio = "en"; break;
case "Giorni della settimana selezionati":  	$messaggio = "Selecteer week dagen"; break;
case "Lunedì":  				$messaggio = "Maandag"; break;
case "Martedì":  				$messaggio = "Disndag"; break;
case "Mercoledì":  				$messaggio = "Woensdag"; break;
case "Giovedì":  				$messaggio = "Donderdag"; break;
case "Venerdì":  				$messaggio = "Vrijdag"; break;
case "Sabato":  				$messaggio = "Zaterdag"; break;
case "Domenica":  				$messaggio = "Zondag"; break;
case "Moltiplicare il costo per":  		$messaggio = "Vermenigvuldig de kosten met"; break;
case "Uno":  					$messaggio = "Een"; break;
case "Chiedere":  				$messaggio = "Vraag"; break;
case "Numero di persone":  			$messaggio = "Aantal mensen"; break;
case "Numero di persone totale":  		$messaggio = "Totaal aantal mensen"; break;
case "escluse quelle dei costi con letti aggiuntivi":	$messaggio = "exclusief de kosten met extra bedden"; break;
case "Periodi in cui è permesso inserire il costo":	$messaggio = "Periodes waar het toegestaan is kosten in te voegen"; break;
case "In tutti":  				$messaggio = "Alles"; break;
case "Solo nei periodi selezionati":  		$messaggio = "Alleen geselcteerde periodes"; break;
case "dal":  					$messaggio = "van"; break;
case "Elimina un periodo":  			$messaggio = "Wis periodes"; break;
case "Aggiungi un periodo":  			$messaggio = "Voeg periode toe"; break;
case "se tutte le settimane della prenotazione sono all'interno dei periodi selezionati":	$messaggio = "als alle weken van reservering zich in de geselecteerde periode bevinden"; break;
case "se tutti i giorni della prenotazione sono all'interno dei periodi selezionati":	$messaggio = "als alle dagen van reservering zich in de geselecteerde periode bevinden"; break;
case "se anche una sola settimana della prenotazione è all'interno dei periodi selezionati":	$messaggio = "als slecht een week zich in de geselecteerde periodes bevindt"; break;
case "se anche un solo giorno della prenotazione è all'interno dei periodi selezionati":	$messaggio = "als slecht een dag zich in de geselecteerde periodes bevindt"; break;
case "applicare il costo solo in settimane permesse all'interno della prenotazione":	$messaggio = "voeg de kosten alleen toe in de toegestane weken van reservering"; break;
case "applicare il costo solo in giorni permessi all'interno della prenotazione":	$messaggio = "voeg de kosten alleen toe in de toegestane dagen van reservering"; break;
case "Caratteristiche del costo da mantenere quando si modifica una prenotazione":	$messaggio = "Kosten eigenschappen blijvend na een wijziging in resevering"; break;
case "Valore percentuale":  			$messaggio = "Percentage waarde"; break;
case "e settimane associate":  			$messaggio = "en gekoppelde weken"; break;
case "e giorni associati":  			$messaggio = "en gekoppelde dagen"; break;
case "Assegnazione settimane":  		$messaggio = "Week toewijzingen"; break;
case "Assegnazione giorni":  			$messaggio = "Dag toewijzingen"; break;
case "Numero per cui viene moltiplicato":  	$messaggio = "Het aantal keren waarmee vermeniguldigd"; break;
case "Periodi permessi":  			$messaggio = "Toegestane periodes"; break;
case "Associazione alle tariffe":  		$messaggio = "Gekoppeld aan tarieven"; break;
case "Mostrare nella pagina di inserimento delle prenotazioni":	$messaggio = "Laat zien in reservering invoeg pagina"; break;
case "Si":  					$messaggio = "Ja"; break;
case "No":  					$messaggio = "Nee"; break;
case "Considerare il costo come letto/i aggiuntivo/i":	$messaggio = "Veronderstel deze extra kosten als extra bed(den)"; break;
case "Limitarne il numero che è possibile avere contemporaneamente in uno stesso periodo":	$messaggio = "Limiet aantal dat mogelijk is in de bijbehorende tijd in de zelfde periode"; break;
case "Valore del costo":  			$messaggio = "Bedrag van de kosten"; break;
case "fisso di":  				$messaggio = "vast vanaf"; break;
case "percentuale su":  			$messaggio = "percentage aan"; break;
case "la tariffa":  				$messaggio = "het tarief"; break;
case "indietro":  				$messaggio = "terug"; break;
case "avanti":  				$messaggio = "vooruit"; break;
case "del":  					$messaggio = "van"; break;
case "arrotondato a":  				$messaggio = "afgerond naar"; break;
case "Errore nei valori inseriti":  		$messaggio = "Fout in igeveoegde waardes"; break;
case "Assegnare automaticamente con le tariffe selezionate":	$messaggio = "Koppel automatisch met gekozen tarief"; break;
case "Tariffe":  				$messaggio = "Tarieven"; break;
case "Il costo aggiuntivo":  			$messaggio = "De extra kosten"; break;
case "OK":  					$messaggio = "OK"; break;
case "Le settimane a cui applicare il costo":	$messaggio = "Weken waaraan kosten worden toegevoegd"; break;
case "I giorni a cui applicare il costo":	$messaggio = "Dagen waaraan kosten worden toegevoegd"; break;
case "uno":  					$messaggio = "een"; break;
case "NO":  					$messaggio = "NEE"; break;
case "SI":  					$messaggio = "JA"; break;
case "Tariffe incompatibili con il costo":  	$messaggio = "Tarieven die niet passen bij de kosten"; break;
case "Tariffe incompatibili":  			$messaggio = "Niet passende kosten"; break;
case "dalla":  					$messaggio = "van"; break;
case "I prezzi della tariffa selezionata sono stati importati":	$messaggio = "TDe prijzen van het gekozen tarief zijn geimporteerd"; break;
case "importa":  				$messaggio = "importeer"; break;
case "o più prenotazioni contemporaneamente":	$messaggio = "or more reservations are inserted contemporarely"; break;
case "è":  					$messaggio = "is"; break;
case "il":  					$messaggio = "the"; break;
case "sono":  					$messaggio = "are"; break;
case "Sulla":  					$messaggio = "On"; break;
case "p":  					$messaggio = "p"; break;
case "Se":  					$messaggio = "If"; break;
case "Se si inseriscono":  			$messaggio = "If"; break;
case "a":  					$messaggio = "to"; break;
case "Crea Prezzi":  				$messaggio = "Insert Prices"; break;
case "La caparra normale per":  		$messaggio = "The normal deposit for"; break;
case "Il costo aggiuntivo percentuale":		$messaggio = "The percentage extra cost"; break;
case "Inserzione per giorni":			$messaggio = "Insertion on daily basis"; break;
case "Inserzione per settimane":  		$messaggio = "Insertion on weekly basis"; break;
case "unico":  					$messaggio = "single"; break;
case "minimo":  				$messaggio = "minimum"; break;
case "massimo":  				$messaggio = "maximum"; break;
case "Costo aggiuntivo già esistente":  	$messaggio = "Extra cost already inserted"; break;
case "i prezzi della":  			$messaggio = "the prices to"; break;
case "aggiungendo":  				$messaggio = "adding"; break;
case "se selezionato mantenere anche":  	$messaggio = "if selected keep also"; break;
case "Quando possibile assegna automaticamente se mancano":	$messaggio = "When possible assign automatically if"; break;
case "meno di":  				$messaggio = "less than"; break;
case "più di":  				$messaggio = "more than"; break;
case "giorni dalla data iniziale della prenotazione quando viene inserita":	$messaggio = "days are remaining from the starting date of the reservation when it is inserted"; break;
case "Quando possibile assegna automaticamente se si inseriscono":	$messaggio = "When possible assign automatically if"; break;
case "Modifica il costo":  			$messaggio = "Modify the cost"; break;
case "Inserisci un nuovo costo aggiuntivo chiamato":	$messaggio = "Insert a new extra cost called"; break;
case "importando le caratteristiche da":	$messaggio = "importing settings from"; break;
case "Sempre in periodi permessi":  		$messaggio = "Always in allowed periods"; break;
case "Prezzo dell'intera settimana":  		$messaggio = "Price of entire week"; break;
case "Prezzi dei giorni":  			$messaggio = "Prices of days"; break;
case "tra":  					$messaggio = "between"; break;
case "Beni dell'inventario da eliminare quando si inserisce il costo":	$messaggio = "Inventory items to delete when the cost is inserted"; break;
case "Nessuno":  				$messaggio = "No one"; break;
case "Beni selezionati":  			$messaggio = "Selected items"; break;
case "Aggiungi un bene":  			$messaggio = "Add an item"; break;
case "Elimina un bene":  			$messaggio = "Delete an item"; break;
case "elimina i beni dall'inventario del magazzino":	$messaggio = "Delete items from inventory of stockroom"; break;
case "Beni dell'inventario da eliminare":  	$messaggio = "Inventory items to delete"; break;
case "Mostrare raggruppato con costi simili della stessa categoria in inserimento":	$messaggio = "Display grouped with similar costs from same category in insertion"; break;
case "Il tipo di applicazione della":  		$messaggio = "The enforcement type of"; break;
case "per persona":  				$messaggio = "per person"; break;
case "per settimana":  				$messaggio = "per week"; break;
case "per giorno":  				$messaggio = "per day"; break;
case "La caparra è errata":  			$messaggio = "The deposit is wrong"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "Le commissioni normali su":  		$messaggio = "The normal commissions on"; break;
case "Inserisci o modifica le commissioni":  	$messaggio = "Insert or modify commissions"; break;
case "Tasse":  					$messaggio = "Taxes"; break;
case "Tasse applicate su":  			$messaggio = "Taxes applied on"; break;
case "della tariffa":  				$messaggio = "of the rate"; break;
case "Inserisci o modifica le tasse":  		$messaggio = "Insert or modify taxes"; break;
case "Le commissioni sono state modificate":  	$messaggio = "Commissions have been modified"; break;
case "Le commissioni sono errate":  		$messaggio = "Commissions are wrong"; break;
case "Le tasse sono state modificate":  	$messaggio = "Taxes have been modified"; break;
case "Le tasse sono errate":  			$messaggio = "Taxes are wrong"; break;
case "tutti i prezzi delle tariffe si intendono con tasse già incluse":	$messaggio = "All rate prices are considered as already including taxes"; break;
case "Inserisci o modifica le commissioni normali":  	$messaggio = "Insert or modify the normal commissions"; break;
case "Inserisci o modifica le commissioni in questo periodo":  	$messaggio = "Insert or modify commissions in this period"; break;
case "al giorno":  				$messaggio = "per day"; break;
case "alla settimana":  			$messaggio = "per week"; break;
case "il valore del costo si intente con tasse già incluse":	$messaggio = "the cost value is considered as already including taxes"; break;
case "Categoria":  				$messaggio = "Category"; break;
case "il prezzo della tariffa per i primi":  	$messaggio = "the rate price for the first"; break;
case "il prezzo della tariffa per le prime":  	$messaggio = "the rate price for the first"; break;
case "della":  					$messaggio = "of the"; break;
case "tariffa + sconto":  			$messaggio = "rate + discount"; break;
case "tariffa + sconto + costi agg.":  		$messaggio = "rate + discount + extra costs"; break;
case "della tar.":  				$messaggio = "of rate"; break;
case "di t.+s.":  				$messaggio = "of r.+d."; break;
case "di t.+s.+c.a.":  				$messaggio = "of r.+d.+e.c."; break;
case "Nome della":  				$messaggio = "Name of"; break;
case "Cambia":  				$messaggio = "Change"; break;
case "prezzo per settimana":  			$messaggio = "price per week"; break;
case "prezzo per giorno":  			$messaggio = "price per day"; break;
case "prezzo per persona per settimana":  	$messaggio = "price per person per week"; break;
case "prezzo per persona per giorno":  		$messaggio = "price per person per day"; break;
case "parte fissa della tariffa":  		$messaggio = "fixed part of the rate"; break;
case "parte per una persona della tariffa":  	$messaggio = "one person part of the rate"; break;
case "Numero massimo":  			$messaggio = "Maximum number"; break;
case "0 se illimitato":  			$messaggio = "0 for unlimited"; break;
case "meno":  					$messaggio = "minus"; break;
case "il costo viene moltiplicato per zero se la somma è negativa":	$messaggio = "the cost will be multiplied by zero if the sum is negative"; break;
case "Combina con altri costi":			$messaggio = "Combine with other costs"; break;
case "i costi combinabili vengono mostrati tutti assieme con il nome della categoria ed ognuno è inserito se possibile":	$messaggio = "combined costs are shown all together with category name and each one is inserted when possible"; break;
case "opzionale":  				$messaggio = "optional"; break;
case "Costi combinati":  			$messaggio = "Combined costs"; break;
case "Inserimento rapido di un nuovo costo aggiuntivo per":	$messaggio = "Fast insertion of a new extra cost for"; break;
case "permanenza minima":  			$messaggio = "minimum stay"; break;
case "numero di neonati":  			$messaggio = "number of infants"; break;
case "letto aggiuntivo":  			$messaggio = "extra bed"; break;
case "offerta speciale":  			$messaggio = "special offer"; break;
case "inserisci":  				$messaggio = "insert"; break;
case "Inserisci il costo aggiuntivo":  		$messaggio = "Insert the extra cost"; break;
case "Numero minimo di giorni":  		$messaggio = "Minimum number of days"; break;
case "Applicato alle tariffe":  		$messaggio = "Applied to rates"; break;
case "Periodi in cui viene applicato il costo":	$messaggio = "Periods in which the cost is applied"; break;
case "Valore per ogni neonato":  		$messaggio = "Value for each infant"; break;
case "del prezzo di una persona":  		$messaggio = "of the price for one person"; break;
case "solo per tariffe con prezzi a persona":  	$messaggio = "only for rates with per person prices"; break;
case "con questo costo il numero di neonati non è incluso nel numero di persone":	$messaggio = "with this cost the number of infants is not included in the number of people"; break;
case "Valore del letto aggiuntivo":  		$messaggio = "Value of the extra bed"; break;
case "Valore dello sconto":  			$messaggio = "Discount value"; break;
case "del prezzo totale":  			$messaggio = "of total price"; break;
case "Se la prenotazione ha una durata di":	$messaggio = "If the reservation length is"; break;
case "o più giorni":  				$messaggio = "days or more"; break;
case "Importa ora":  				$messaggio = "Import now"; break;
case "Importa sempre":  			$messaggio = "Always import"; break;
case "cancella":  				$messaggio = "delete"; break;
case "L'importatazione dei prezzi è stata cancellata":	$messaggio = "The prices import has been deleted"; break;
case "al prezzo fisso":  			$messaggio = "to fixed price"; break;
case "al prezzo per persona":  			$messaggio = "to per person price"; break;
case "ad entrambi i prezzi":  			$messaggio = "to both prices"; break;
case "La tariffa":  				$messaggio = "The rate"; break;
case "esporta i prezzi ad altre tariffe, non può importare i prezzi in modo permanente":	$messaggio = "exports its prices to other rates, it can't import prices permanently"; break;
case "tutte le tariffe":  			$messaggio = "all rates"; break;
case "considerare l'intero costo come tasse":  	$messaggio = "consider the entire cost as taxes"; break;
case "Escludere questo costo dal totale per altri costi percentuali":	$messaggio = "Exclude this cost from the total for other percentage costs"; break;
case "in tutti i periodi in modo predefinito":	$messaggio = "in all periods by default"; break;
case "importa i prezzi da altre tariffe, non può esportare i prezzi":	$messaggio = "imports its prices from other rates, so can't export its prices"; break;
case "importa già i prezzi da altre tariffe in questi periodi, non può importare altri prezzi":	$messaggio = "already imports its prices from other rates in these periods, can't import other prices"; break;
case "modifica":  				$messaggio = "modify"; break;
case "In modo predefinito importa":  		$messaggio = "By default import"; break;
case "i prezzi di alcuni periodi <em>non sono stati inseriti</em> perchè importati da altre tariffe":	$messaggio = "the prices of some periods <em>have not been inserted</em> because they are imported from other rates"; break;
case "limite non considerato per le persone aggiuntive nelle interconnessioni":	$messaggio = "limit not considered for additional people in interconnections"; break;
case "Seleziona adesso questo costo anche per tutti gli utenti che non hanno privilegi per usare tutti i costi":	$messaggio = "Select now this cost also for all the users that don't have privileges to use all the costs"; break;
case "Aggiungi adesso questo costo a tutte le pagine create per il sito web":	$messaggio = "Add now this cost to all existing website pages"; break;
case "Se si moltiplica per il numero di persone":	$messaggio = "When multiplying by the number of people"; break;
case "escludi":  				$messaggio = "exclude"; break;
case "includi solo":  				$messaggio = "include only"; break;
case "questi tipi":  				$messaggio = "these types"; break;
case "Mostrare come tipo di persona":  		$messaggio = "Display as person type"; break;
case "Applicare la percentuale del tipo di persona al prezzo del costo":	$messaggio = "Apply the percentage of the person type to the price of the cost"; break;
case "Neonati (0-23 mesi)":  			$messaggio = "Infants (0-23 months)"; break;
case "tariffe con":  				$messaggio = "rates with"; break;
case "per persona nullo":  			$messaggio = "per person zero"; break;
case "fisso nullo":  				$messaggio = "fixed zero"; break;
case "da per persona":  			$messaggio = "from per person"; break;
case "più fisso":  				$messaggio = "from fixed"; break;
case "dal fisso":  				$messaggio = "plus fixed"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>